@@ -7,7 +7,7 @@ our @EXPORT = qw(update_bakefile_0);
 use strict;
 use warnings;
 
-our $VERSION = '0.3'; # VERSION
+our $VERSION = '0.4'; # VERSION
 
 
 
@@ -35,6 +35,8 @@ sub update_bakefile_0
             s/<!-- .* -->//;
             s/^\s+//;
             s/\s+$//;
+            s{<if [^>]+>}{};
+            s{</if>}{};
             if (m{</set>}) {
                 # Check if we have any new files.
                 #
@@ -84,7 +86,7 @@ Makefile::Update::Bakefile0 - Update bakefile-0.x files list.
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 SYNOPSIS
 
